@@ -13,21 +13,18 @@ from requests_toolbelt.multipart.encoder import MultipartEncoder
 from yop_python_sdk.client.yop_client_config import YopClientConfig
 import yop_python_sdk.utils.yop_logger as yop_logger
 
-SDK_VERSION = '4.2.0'
+SDK_VERSION = '4.2.1'
 platform_info = platform.platform().split("-")
 python_compiler = platform.python_compiler().split(' ')
 locale_info = locale.getdefaultlocale()
 locale_lang = locale_info[0]
 if locale_lang is None:
     locale_lang = 'zh-CN'
-USER_AGENT = "/".join(['python',
-                       SDK_VERSION,
-                       platform_info[0],
-                       platform_info[1],
-                       python_compiler[0],
-                       python_compiler[1],
-                       platform.python_version(),
-                       locale_lang])
+USER_AGENT = "/".join([
+    'python', SDK_VERSION, platform_info[0], platform_info[1],
+    python_compiler[0], python_compiler[1],
+    platform.python_version(), locale_lang
+])
 
 
 class YopClient:
@@ -51,7 +48,8 @@ class YopClient:
 
         # 同时支持RSA、SM两种加密机
         self.yop_encryptor_dict = {}
-        for cert_type, yop_public_key_dict in clientConfig.sdk_config['yop_public_key'].items():
+        for cert_type, yop_public_key_dict in clientConfig.sdk_config[
+                'yop_public_key'].items():
             if len(yop_public_key_dict) > 0:
                 self.yop_encryptor_dict[cert_type] = self.get_encryptor(
                     cert_type, yop_public_key_dict)
@@ -71,7 +69,8 @@ class YopClient:
         if 'SM2' == cert_type:
             return SmEncryptor(public_key_dict=yop_public_key_dict)
         else:
-            return RsaEncryptor(public_key=list(yop_public_key_dict.values())[0])
+            return RsaEncryptor(
+                public_key=list(yop_public_key_dict.values())[0])
 
     def get(self, api, query_params={}, credentials=None, basePath=None):
         """
@@ -91,20 +90,23 @@ class YopClient:
             basePath = self.clientConfig.get_server_root()
 
         authorization = self.authProvider.new_authenticator()
-        headers = authorization.generate_signature(
-            url=api, http_method='GET', query_params=query_params,
-            credentials=credentials)
+        headers = authorization.generate_signature(url=api,
+                                                   http_method='GET',
+                                                   query_params=query_params,
+                                                   credentials=credentials)
         headers['user-agent'] = USER_AGENT
 
         # for k, v in query_params.items():
         #         query_params[k] = quote(str(v), 'utf-8')
 
         url = ''.join([basePath, api])
-        res = self._get_request(
-            url, query_params=query_params, headers=headers)
+        res = self._get_request(url,
+                                query_params=query_params,
+                                headers=headers)
         self.logger.info(
-            'request:\nGET {}\nheaders:{}\nparams:{}\nresponse:\nheaders:{}\nbody:{}\ntime:{}ms\n'.format(
-                url, headers, query_params, res.headers, res.text, res.elapsed.microseconds / 1000.))
+            'request:\nGET {}\nheaders:{}\nparams:{}\nresponse:\nheaders:{}\nbody:{}\ntime:{}ms\n'
+            .format(url, headers, query_params, res.headers, res.text,
+                    res.elapsed.microseconds / 1000.))
 
         if res.status_code == 400:
             raise Exception("isv.service.not-exists")
@@ -116,7 +118,12 @@ class YopClient:
             self.logger.warn(res.text)
             raise e
 
-    def download(self, api, query_params={}, credentials=None, basePath=None, file_path=None):
+    def download(self,
+                 api,
+                 query_params={},
+                 credentials=None,
+                 basePath=None,
+                 file_path=None):
         """
         Downloads the specified API from the server.
 
@@ -135,20 +142,23 @@ class YopClient:
             basePath = self.clientConfig.get_server_root()
 
         authorization = self.authProvider.new_authenticator()
-        headers = authorization.generate_signature(
-            url=api, http_method='GET', query_params=query_params,
-            credentials=credentials)
+        headers = authorization.generate_signature(url=api,
+                                                   http_method='GET',
+                                                   query_params=query_params,
+                                                   credentials=credentials)
         headers['user-agent'] = USER_AGENT
 
         # for k, v in query_params.items():
         #         query_params[k] = quote(str(v), 'utf-8')
 
         url = ''.join([basePath, api])
-        res = self._get_request(
-            url, query_params=query_params, headers=headers)
-        self.logger.info(
-            'request:\nGET {}\nheaders:{}\nparams:{}\nresponse:\nheaders:{}\ntime:{}ms\n'.format(
-                url, headers, query_params, res.headers, res.elapsed.microseconds / 1000.))
+        res = self._get_request(url,
+                                query_params=query_params,
+                                headers=headers)
+        self.logger.debug(
+            'request:\nGET {}\nheaders:{}\nparams:{}\nresponse:\nheaders:{}\ntime:{}ms\n'
+            .format(url, headers, query_params, res.headers,
+                    res.elapsed.microseconds / 1000.))
 
         if res.status_code == 400:
             raise Exception("isv.service.not-exists")
@@ -160,8 +170,8 @@ class YopClient:
                 self.logger.warn(res.text)
                 raise e
 
-        filename = res.headers['Content-Disposition'].split(
-            '; ')[1].replace('filename=', '')
+        filename = res.headers['Content-Disposition'].split('; ')[1].replace(
+            'filename=', '')
         filename = filename[filename.rindex('/') + 1:len(filename)]
 
         try:
@@ -170,8 +180,9 @@ class YopClient:
             full_filename = file_path + '/' + filename
             with open(full_filename, "wb+") as file:
                 file.write(res.content)
-                authorization._verify_res_download(
-                    res, credentials.get_cert_type(), file)
+                authorization._verify_res_download(res,
+                                                   credentials.get_cert_type(),
+                                                   file)
             return 0
         except OSError as e:
             self.logger.warn('找不到文件路径:{}'.format(file_path))
@@ -179,9 +190,7 @@ class YopClient:
         else:
             return 1
 
-    def _get_request(self,
-                     url, query_params={},
-                     headers={}):
+    def _get_request(self, url, query_params={}, headers={}):
         """
         Wrapper for requests. get that handles the headers and returns the response.
 
@@ -194,12 +203,7 @@ class YopClient:
         res = requests.get(url=url, params=query_params, headers=headers)
         return res
 
-    def post_json(
-            self,
-            api,
-            post_params={},
-            credentials=None,
-            basePath=None):
+    def post_json(self, api, post_params={}, credentials=None, basePath=None):
         """
         POST the specified post params to the specified API
 
@@ -210,9 +214,18 @@ class YopClient:
             credentials: write your description
             basePath: write your description
         """
-        return self.post(api, post_params, credentials, basePath=basePath, json_param=True)
+        return self.post(api,
+                         post_params,
+                         credentials,
+                         basePath=basePath,
+                         json_param=True)
 
-    def post(self, api, post_params={}, credentials=None, basePath=None, json_param=False):
+    def post(self,
+             api,
+             post_params={},
+             credentials=None,
+             basePath=None,
+             json_param=False):
         """
         Make a POST request to the API.
 
@@ -231,10 +244,11 @@ class YopClient:
             basePath = self.clientConfig.get_server_root()
 
         authorization = self.authProvider.new_authenticator()
-        headers = authorization.generate_signature(
-            url=api, http_method='POST', post_params=post_params,
-            credentials=credentials,
-            json_param=json_param)
+        headers = authorization.generate_signature(url=api,
+                                                   http_method='POST',
+                                                   post_params=post_params,
+                                                   credentials=credentials,
+                                                   json_param=json_param)
         headers['user-agent'] = USER_AGENT
 
         # for k, v in post_params.items():
@@ -244,9 +258,11 @@ class YopClient:
 
         if json_param:
             headers['content-type'] = 'application/json'
-            data = simplejson.dumps(
-                post_params, sort_keys=True, indent=4, separators=(
-                    ',', ': '), ensure_ascii=True).encode("latin-1")
+            data = simplejson.dumps(post_params,
+                                    sort_keys=True,
+                                    indent=4,
+                                    separators=(',', ': '),
+                                    ensure_ascii=True).encode("latin-1")
             res = self._post_request(url, payload=data, headers=headers)
         else:
             res = self._post_request(url, params=post_params, headers=headers)
@@ -279,15 +295,14 @@ class YopClient:
             basePath = self.clientConfig.get_yos_server_root()
 
         authorization = self.authProvider.new_authenticator()
-        headers = authorization.generate_signature(
-            url=api, http_method='POST', post_params=post_params,
-            credentials=credentials)
+        headers = authorization.generate_signature(url=api,
+                                                   http_method='POST',
+                                                   post_params=post_params,
+                                                   credentials=credentials)
         headers['user-agent'] = USER_AGENT
 
         # 封装文件上传编码器
-        multipart = MultipartEncoder(
-            fields=post_params
-        )
+        multipart = MultipartEncoder(fields=post_params)
         headers['content-type'] = multipart.content_type
 
         url = ''.join([basePath, api])
@@ -296,8 +311,8 @@ class YopClient:
         if res.status_code == 400:
             raise Exception("isv.service.not-exists")
 
-        authorization._verify_res_upload(
-            res, credentials.get_cert_type(), post_params)
+        authorization._verify_res_upload(res, credentials.get_cert_type(),
+                                         post_params)
         try:
             return simplejson.loads(res.text)
         except JSONDecodeError as e:
@@ -315,9 +330,12 @@ class YopClient:
             params: write your description
             headers: write your description
         """
-        res = requests.post(url=url, headers=headers,
-                            data=payload, params=params)
+        res = requests.post(url=url,
+                            headers=headers,
+                            data=payload,
+                            params=params)
         self.logger.debug(
-            'request:\nPOST {}\nheaders:{}\nparams:{}\nresponse:\nheaders:{}\nbody:{}\ntime:{}ms\n'.format(
-                url, headers, params, res.headers, res.text, res.elapsed.microseconds / 1000.))
+            'request:\nPOST {}\nheaders:{}\nparams:{}\nresponse:\nheaders:{}\nbody:{}\ntime:{}ms\n'
+            .format(url, headers, params, res.headers, res.text,
+                    res.elapsed.microseconds / 1000.))
         return res
